## START: Set by rpmautospec
## (rpmautospec version 0.6.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Owns: /usr/lib/python3.10/site-packages/keyrings/__init__.py
# So keep an eye out for any other packages that may also want to owns it.

%bcond tests 1

# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a substitute.
%bcond doc 0
# Currently disabled, something missing:
# Could not import extension jaraco.packaging.sphinx (exception: No module named 'domdf_python_tools')

%global _description %{expand:
Alternate keyring backend implementations for use with the keyring package.

Keyrings in this package may have security risks or other implications. These
backends were extracted from the main keyring project to make them available
for those who wish to employ them, but are discouraged for general production
use. Include this module and use its backends at your own risk.

For example, the PlaintextKeyring stores passwords in plain text on the file
system, defeating the intended purpose of this library to encourage best
practices for security.}

%global forgeurl  https://github.com/jaraco/keyrings.alt

Name:           python-keyrings-alt
Version:        5.0.1
Release:        %{autorelease}
Summary:        Alternate keyring implementations

%forgemeta

# SPDX
License:        MIT
URL:            %forgeurl
Source0:        %forgesource

BuildArch:      noarch

%description %_description

%package -n python3-keyrings-alt
Summary:        %{summary}
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  gnome-keyring
%endif
# Not included in install_requires
Requires:       %{py3_dist keyring}
%if %{without doc}
Provides:       python-keyrings-alt-doc = %{version}-%{release}
Obsoletes:      python-keyrings-alt-doc < %{version}-2
%endif

%description -n python3-keyrings-alt %_description

%if %{with doc}
%package doc
Summary:        Documentation for %{name}

BuildRequires:  make
BuildRequires:  python3-sphinx-latex
BuildRequires:  python3-jaraco-packaging
BuildRequires:  python3-jaraco-context
BuildRequires:  latexmk

%description doc
This package provides documentation for %{name}.
%endif

%prep
%forgesetup

# Remove backports, used for Py <=3.2
sed -r -i '/backports\.unittest_mock/ d' setup.cfg
# Remove linters and coverage from BR
sed -r -i \
    -e '/pytest-(black|cov|checkdocs|mypy|enabler|ruff)/ d' \
    -e '/python_implementation != "PyPy"/ d' \
    -e '/sphinx-lint/ d' \
    setup.cfg
# We cannot have a pycryptodome test dependency, since there is no
# python-pycryptodome package (it would conflict with python-crypto/pycrypto).
# However, the tests intended for pycryptodome will pass with pycrypto
# installed, so we simply adjust the dependency.
sed -r -i 's/(pycrypto)dome$/\1/' setup.cfg

%if %{with doc}
# The 'jaraco.packaging.sphinx' extension means sphinx-build attempts to
# download things from PyPI. Obviously, we can’t have this.
sed -r -i 's/, .jaraco\.packaging\.sphinx.//' docs/conf.py
# The 'rst.linker' extension doesn’t seem to work for us. Maybe this is because
# we patched out 'jaraco.packaging.sphinx' (or maybe it isn’t).
sed -r -i 's/, .rst\.linker.//' docs/conf.py
# This isn’t packaged; it seems to be used only for the Tidelift referral
# banner in the documentation.
sed -r -i "s/(, )?'jaraco\\.tidelift'//g" docs/conf.py
sed -i -e '/jaraco\.tidelift/ d' setup.cfg
%endif

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_buildrequires -r %{?with_tests:-x testing} %{?with_doc:-x docs}

# gdata, keyczar are Py2 only
# pyfs is included as python-fs but tests are still skipped
# Also skipped upstream though: https://github.com/jaraco/keyrings.alt/runs/3082737541?check_suite_focus=true

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%if %{with doc}
PYTHONPATH="${PWD}" sphinx-build-3 docs docs/_latex -b latex %{?_smp_mflags}
%make_build -C docs/_latex LATEXMKOPTS='-quiet'
mv docs/_latex/python.pdf docs/_latex/keyringsalt.pdf
%endif

%install
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_install
%pyproject_save_files -l keyrings

%check
%if %{with tests}
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%{pytest}
%endif

%files -n python3-keyrings-alt -f %{pyproject_files}
%doc README.rst

%if %{with doc}
%files doc
%license LICENSE
%doc docs/_latex/keyringsalt.pdf
%endif

%changelog
## START: Generated by rpmautospec
* Tue Apr 02 2024 Packit <hello@packit.dev> - 5.0.1-1
- [packit] 5.0.1 upstream release
- Resolves: rhbz#2272573

* Sun Feb 25 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 5.0.0-7
- chore: use new bconds, forge macros

* Sat Feb 24 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 5.0.0-6
- chore: add packit

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 03 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 5.0.0-3
- Assert that the .dist-info directory contains a license file

* Sun Nov 05 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 5.0.0-2
- feat: update to conditionally turn off docs

* Thu Oct 12 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 5.0.0-1
- feat: update to 5.0.0

* Thu Oct 12 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 4.2.0-5
- chore: add packit conf

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Jul 01 2023 Python Maint <python-maint@redhat.com> - 4.2.0-3
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Sep 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.2.0-1
- Update to 4.2.0 (close RHBZ#2124132)

* Mon Sep 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.1.2-2
- Note that license is *SPDX* MIT

* Mon Sep 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.1.2-1
- Update to 4.1.2

* Fri Sep 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.1.0-6
- Build LaTeX more quietly

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> - 4.1.0-4
- Rebuilt for Python 3.11

* Thu Mar 24 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 4.1.0-3
- Fix doc build and convert to PDF (fix RHBZ#2068264)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Sep 08 2021 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 4.1.0-1
- feat: init
## END: Generated by rpmautospec
